@@ -66,6 +66,12 @@ def dtypes_to_json_task(dtypes_dict, local_json_path: str):
 
 @task
 def chunk_df(df: pd.DataFrame, size: int = 10_000) -> List[pd.DataFrame]:
+    """
+    Creates pandas Dataframes list of chunks with a given size.
+    Args:
+        df (pd.DataFrame): Input pandas DataFrame.
+        size (int, optional): Size of a chunk. Defaults to 10000.
+    """
     n_rows = df.shape[0]
     chunks = [df[i : i + size] for i in range(0, n_rows, size)]
     return chunks
@@ -73,6 +79,11 @@ def chunk_df(df: pd.DataFrame, size: int = 10_000) -> List[pd.DataFrame]:
 
 @task
 def df_get_data_types_task(df: pd.DataFrame) -> dict:
+    """
+    Returns dictionary containing datatypes of pandas DataFrame columns.
+    Args:
+        df (pd.DataFrame): Input pandas DataFrame.
+    """
     typeset = CompleteSet()
     dtypes = infer_type(df, typeset)
     dtypes_dict = {k: str(v) for k, v in dtypes.items()}
@@ -127,16 +138,35 @@ def df_to_csv(
     if_exists: Literal["append", "replace", "skip"] = "replace",
     **kwargs,
 ) -> None:
+
+    """
+    Task to create csv file based on pandas DataFrame.
+    Args:
+    df (pd.DataFrame): Input pandas DataFrame.
+    path (str): Path to output csv file.
+    sep (str, optional): The separator to use in the CSV. Defaults to "\t".
+    if_exists (Literal["append", "replace", "skip"], optional): What to do if the table exists. Defaults to "replace".
+    """
+
     if if_exists == "append" and os.path.isfile(path):
         csv_df = pd.read_csv(path, sep=sep)
         out_df = pd.concat([csv_df, df])
     elif if_exists == "replace":
         out_df = df
-    elif if_exists == "skip":
+    elif if_exists == "skip" and os.path.isfile(path):
         logger.info("Skipped.")
         return
     else:
         out_df = df
+
+    # create directories if they don't exist
+    try:
+        if not os.path.isfile(path):
+            directory = os.path.dirname(path)
+            os.makedirs(directory, exist_ok=True)
+    except:
+        pass
+
     out_df.to_csv(path, index=False, sep=sep)
 
 
@@ -147,6 +177,13 @@ def df_to_parquet(
     if_exists: Literal["append", "replace", "skip"] = "replace",
     **kwargs,
 ) -> None:
+    """
+    Task to create parquet file based on pandas DataFrame.
+    Args:
+    df (pd.DataFrame): Input pandas DataFrame.
+    path (str): Path to output parquet file.
+    if_exists (Literal["append", "replace", "skip"], optional): What to do if the table exists. Defaults to "replace".
+    """
     if if_exists == "append" and os.path.isfile(path):
         parquet_df = pd.read_parquet(path)
         out_df = pd.concat([parquet_df, df])
@@ -162,18 +199,34 @@ def df_to_parquet(
 
 @task
 def dtypes_to_json(dtypes_dict: dict, local_json_path: str) -> None:
+    """
+    Creates json file from a dictionary.
+    Args:
+        dtypes_dict (dict): Dictionary containing data types.
+        local_json_path (str): Path to local json file.
+    """
     with open(local_json_path, "w") as fp:
         json.dump(dtypes_dict, fp)
 
 
 @task
 def union_dfs_task(dfs: List[pd.DataFrame]):
+    """
+    Create one DataFrame from a list of pandas DataFrames.
+    Args:
+        dfs (List[pd.DataFrame]): List of pandas Dataframes to concat. In case of different size of DataFrames NaN values can appear.
+    """
     return pd.concat(dfs, ignore_index=True)
 
 
 @task
 def write_to_json(dict_, path):
-
+    """
+    Creates json file from a dictionary. Log record informs about the writing file proccess.
+    Args:
+        dict_ (dict): Dictionary.
+        path (str): Path to local json file.
+    """
     logger = prefect.context.get("logger")
 
     if os.path.isfile(path):
