@@ -16,6 +16,7 @@ from .azure_sql import (
     AzureSQLCreateTable,
     AzureSQLDBQuery,
     CreateTableFromBlob,
+    CheckColumnOrder,
 )
 from .bcp import BCPTask
 from .github import DownloadGitHubFile
@@ -24,3 +25,10 @@ from .sqlite import SQLiteInsert, SQLiteSQLtoDF, SQLiteQuery
 from .supermetrics import SupermetricsToCSV, SupermetricsToDF
 from .sharepoint import SharepointToDF
 from .cloud_for_customers import C4CReportToDF, C4CToDF
+
+try:
+    from .sap_rfc import SAPRFCToDF
+except ImportError:
+    pass
+
+from .duckdb import DuckDBCreateTableFromParquet, DuckDBQuery
